@@ -1,13 +1,16 @@
 # =====================================
 # generator=datazen
-# version=1.14.0
-# hash=43c10539f25ac147cbade36d485c6b93
+# version=2.1.0
+# hash=16d64b8b583d6612bd879395e512162d
 # =====================================
 
 """
-vcorelib - Useful defaults and other package metadata.
+Useful defaults and other package metadata.
 """
 
 DESCRIPTION = "A collection of core Python utilities."
 PKG_NAME = "vcorelib"
-VERSION = "0.2.0"
+VERSION = "0.4.1"
+
+DEFAULT_INDENT = 2
+DEFAULT_ENCODING = "utf-8"
